from my_aws_helpers.logging import select_powertools_logger


logger = select_powertools_logger("aws-helpers-s3")


class Auth:

    @staticmethod
    def get_bearer_from_lambda_event(event: dict) -> str:
        try:
            bearer_token = event["headers"]["Authorization"]
            return str(bearer_token).split("Bearer")[-1]
        except Exception as e:
            logger.exception(f"Failed to get bearer from lambda event due to {e}")
        return None



import boto3
from typing import Optional
import json
from uuid import uuid4
from my_aws_helpers.api import API
from my_aws_helpers.errors import *


class SFN:
    client: boto3.client

    def __init__(self, client: Optional[boto3.client] = None) -> None:
        self.client = client if client else boto3.client("stepfunctions")

    def start_execution(
        self,
        sfn_arn: str,
        event: Optional[dict] = None,
        name: Optional[str] = uuid4().hex,
    ):
        input_event = json.dumps(event) if event else event
        return self.client.start_execution(
            stateMachineArn=sfn_arn,
            name=name,
            input=input_event,
        )

    def handle_error_response(func):
        def wrapper(event, context):
            try:
                response = func(event, context)
                return API.response(code=200, body=json.dumps(response))
            except AlreadyExists as e:
                return API.response(code=201, body=json.dumps({"Success": f"{e}"}))
            except ClientError as e:
                return API.response(code=400, body=json.dumps({"Error": f"{e}"}))
            except NotFoundError as e:
                return API.response(code=404, body=json.dumps({"Error": f"{e}"}))
            except ServerError as e:
                return API.response(code=500, body=json.dumps({"Error": f"{e}"}))
            except Exception as e:
                return API.response(code=500, body=json.dumps({"Error": f"{e}"}))

        return wrapper
